@@ -1,7 +1,7 @@
 package Sidef::Object::Lazy {
 
     use utf8;
-    use 5.014;
+    use 5.016;
     ##use overload q{""} => \&to_a;
 
     sub new {
@@ -18,7 +18,7 @@ package Sidef::Object::Lazy {
 
         my $iter = $self->{obj}->iter;
 
-      ITEM: while (defined(my $item = $iter->())) {
+      ITEM: while (defined(my $item = $iter->run())) {
             my @arg = ($item);
             foreach my $call (@{$self->{calls}}) {
                 @arg = $call->(@arg);
@@ -49,7 +49,7 @@ package Sidef::Object::Lazy {
         Sidef::Types::Block::Block->new(
             code => sub {
               ITEM: {
-                    my $item = $iter->() // return undef;
+                    my $item = $iter->run() // return undef;
                     my @arg  = ($item);
                     foreach my $call (@{$self->{calls}}) {
                         @arg = $call->(@arg);
@@ -82,13 +82,30 @@ package Sidef::Object::Lazy {
         $self->_xs(
             sub {
                 push @arr, @_;
-                @arr >= $n ? 1 : 0;
+                @arr >= $n;
             }
         );
 
         Sidef::Types::Array::Array->new(\@arr);
     }
 
+    sub nth {
+        my ($self, $n) = @_;
+
+        my @arr;
+        $n = CORE::int($n);
+        $n > 0 || return undef;
+
+        $self->_xs(
+            sub {
+                push @arr, @_;
+                @arr >= $n;
+            }
+        );
+
+        $arr[$n - 1];
+    }
+
     sub first_by {
         my ($self, $block) = @_;
         $self->grep($block)->first(1)->[0];
