@@ -1,9 +1,11 @@
 package Sidef::Types::Set::Set {
 
     use utf8;
-    use 5.014;
+    use 5.016;
 
-    use parent qw(Sidef::Types::Hash::Hash);
+    use parent qw(
+      Sidef::Types::Hash::Hash
+      );
 
     use overload
       q{bool} => sub { scalar(CORE::keys(%{$_[0]})) },
@@ -457,6 +459,8 @@ package Sidef::Types::Set::Set {
         *{__PACKAGE__ . '::' . '⊆'}   = \&is_subset;
         *{__PACKAGE__ . '::' . '⊇'}   = \&is_superset;
         *{__PACKAGE__ . '::' . '...'} = \&to_list;
+        *{__PACKAGE__ . '::' . '∋'}   = \&contains;
+        *{__PACKAGE__ . '::' . '∌'}   = sub { $_[0]->contains($_[1])->not };
         *{__PACKAGE__ . '::' . '≡'}   = \&Sidef::Types::Hash::Hash::eq;
     }
 };
